@@ -29,23 +29,15 @@ namespace QPulseAudio
 class Q_DECL_EXPORT SourceOutput : public Stream
 {
     Q_OBJECT
-    Q_PROPERTY(quint32 sourceIndex READ sourceIndex WRITE setSourceIndex NOTIFY sourceIndexChanged)
 public:
     SourceOutput(QObject *parent);
 
     void update(const pa_source_output_info *info);
 
-    quint32 sourceIndex() const;
-    void setSourceIndex(quint32 sourceIndex);
-
     void setVolume(qint64 volume) Q_DECL_OVERRIDE;
     void setMuted(bool muted) Q_DECL_OVERRIDE;
-
-signals:
-    void sourceIndexChanged();
-
-private:
-    quint32 m_sourceIndex = 0;
+    void setChannelVolume(int channel, qint64 volume) Q_DECL_OVERRIDE;
+    void setDeviceIndex(quint32 deviceIndex) Q_DECL_OVERRIDE;
 };
 
 } // QPulseAudio
